;; Generated package description from projectile.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "projectile" "3.4.0snapshot0.20260729.16" "Manage and navigate projects in Emacs easily" '((emacs "28.1") (compat "30")) :commit "71e8f9c49384d78ca868efe41741cece17c2bc6c" :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev")) :maintainer '("Bozhidar Batsov" . "bozhidar@batsov.dev") :keywords '("project" "convenience") :url "https://github.com/bbatsov/projectile")
